@@ -342,9 +342,9 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
     let holeHeight = holeData.properties.get('height').get('length');
 
     pivot.rotation.y = alpha;
-    pivot.position.x = vertex0.x + distance * holeData.offset * Math.cos(alpha) - center[2] * Math.sin(alpha);
+    pivot.position.x = layer.vertices.get(line.vertices.get(0)).x + distance * holeData.offset * Math.cos(alpha) - center[2] * Math.sin(alpha);
     pivot.position.y = holeAltitude + holeHeight / 2 - center[1] + layer.altitude;
-    pivot.position.z = -vertex0.y - distance * holeData.offset * Math.sin(alpha) - center[2] * Math.cos(alpha);
+    pivot.position.z = -layer.vertices.get(line.vertices.get(0)).y - distance * holeData.offset * Math.sin(alpha) - center[2] * Math.cos(alpha);
 
     planData.plan.add(pivot);
     planData.sceneGraph.layers[layer.id].holes[holeData.id] = pivot;
@@ -441,7 +441,6 @@ function applyInteract(object, interactFunction) {
 
 function updateBoundingBox(planData) {
   let newBoundingBox = new Three.Box3().setFromObject(planData.plan);
-
   if (isFinite(newBoundingBox.max.x)
     || isFinite(newBoundingBox.min.x)
     || isFinite(newBoundingBox.max.y)
@@ -462,6 +461,10 @@ function updateBoundingBox(planData) {
     planData.grid.position.y -= newCenter[1];
     planData.grid.position.z -= newCenter[2];
 
+    // Update bounding box
+    newBoundingBox.min.sub(new Three.Vector3().fromArray(newCenter));
+    newBoundingBox.max.sub(new Three.Vector3().fromArray(newCenter));
+
     planData.boundingBox = newBoundingBox;
   }
 }
