@@ -4,9 +4,11 @@ import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
 import * as Models from './models'
 import PluginBrowserAutosave from './plugins/browser-autosave/browser-autosave';
+import State2DViewer from './components/viewer2d/state';
+import AppReducer from './reducers/reducer';
 
 console.info(`react-planner started`); //MIT LICENSE COMPLIANT
 
 export {
-  Planner, Catalog, ToolbarButton, Ruler, Models, PluginBrowserAutosave
+  Planner, Catalog, ToolbarButton, Ruler, Models, PluginBrowserAutosave, State2DViewer, AppReducer
 };
